---
title: "Impacts environnementaux du numérique en France"
description: "Grâce à l’étude de l’ADEME et de l’ARCEP de janvier 2022, quantification et analyse des impacts
environnementaux du numérique en France."
date: 2022-11-21
tags:
  - impacts environnementaux
  - écoconception
  - ACV
authors:
  - Anthony Lecerf
layout: article.njk
---
Le numérique est au cœur de notre quotidien et bouleverse nos modes de vie et de travail. Il a également des effets
négatifs involontaires, entre autres sur notre environnement, qu’il faut absolument chercher à réduire car le numérique
contribue au dépassement de plusieurs limites planétaires, c’est-à-dire aux quantités d’impacts environnementaux
au-dessus desquels nous déstabiliseront les équilibres fondamentaux de la planète.

Rappelons que sur neuf limites planétaires, six ont désormais été dépassées : le changement climatique, l’érosion de la
biodiversité, les perturbations globales du cycle de l’azote et du phosphore, les changements d'utilisation des sols,
l'introduction de nouvelles substances (en 2022) et l’utilisation de l'eau douce (en 2022).

## Principes d’évaluation environnementale

Contrairement à ce que sous-entend l’univers sémantique du numérique ("cloud", dématérialisation, virtualisation...)
**les services numériques ont une matérialité bien réelle** : des équipements et des infrastructures sont nécessaires
pour
exécuter les logiciels, naviguer sur les sites web et utiliser les applications.

C’est bien cette matérialité qui engendre des impacts environnementaux. En effet, un logiciel n’a pas d’impacts
environnementaux à proprement parler (et ne s’écoconçoit pas) alors que les éléments physiques d’un service numérique en
ont.

Pour quantifier et analyser ces impacts, il est important de prendre en compte plusieurs critères environnementaux car
le numérique a bien plus d’effets négatifs que les seules émissions de gaz à effet de serre. Si l’analyse n’est pas
multicritère, le risque que les solutions apportées transfèrent les impacts d’un critère vers un autre est réel.

Il est également essentiel d’avoir une approche multi-étapes et systémique et de considérer l’ensemble des étapes du
cycle de vie de tous les éléments physique sous-jacents à une unité fonctionnelle. On définit l’objet d’une étude par la
fonction qu’il remplit afin de pouvoir comparer différentes solutions.

C’est là tout l’intérêt de **la méthode holistique que représente l’analyse de cycle de vie (ACV)**.
[Une évaluation environnementale](https://www.arcep.fr/uploads/tx_gspublication/etude-numerique-environnement-ademe-arcep-volet02_janv2022.pdf),
basée sur la méthode ACV, pilotée par l’ADEME et l’ARCEP et publiée en janvier 2022, quantifie et analyse les impacts
environnementaux du numérique en France au travers de l’unité fonctionnelle suivante :

"Utiliser les équipements et systèmes basés en France liés aux équipements et infrastructures numériques sur un an"

## Matérialité des équipements et infrastructures numériques en France

Selon cette étude, cette unité fonctionnelle couvre l’utilisation de plus d’un milliard d’équipements utilisateurs
(terminaux) et notamment :

- plus de 120 millions de téléphones, dont 70 millions de smartphones ;
- près de 25 millions de tablettes ;
- près de 60 millions d’ordinateurs portables et 40 millions d’ordinateurs fixes ;
- environ 40 millions d’écrans d’ordinateur et 60 millions de téléviseurs ;
- plus de 20 millions d’imprimantes ;
- environ 245 millions d’objets connectés.

Elle implique également des équipements réseau et des centres informatiques, entre autres :

- environ 30 millions d’abonnés (et donc de box internet) à des réseaux fixes ;
- environs 95 millions d’abonnés à des réseaux mobiles, dont approximativement 20 millions pour des communications entre
  machines ;
- 1,5 million de serveurs ;
- 15 millions de disques durs et SSD.

**La matérialité du numérique est donc très fortement liée aux équipements des utilisateurs : il y a plus de 660
terminaux pour 1 serveur.**

__Nota bene :__ les impacts des équipements réseaux n’ont pas pu se baser sur un nombre d’équipements et leur durée de vie
car les opérateurs et équipementiers n’ont pas pu déterminer cette dernière. L’infrastructure réseau n’a pas été prise
en compte car des données ont aussi manqué à ce niveau. Cela fait partie des limites de cette étude.

## Principaux impacts environnementaux du numérique en France

### Impact sur le changement climatique

Il se définit comme suit : "Les gaz à effet de serre (GES) sont des composés gazeux qui absorbent le rayonnement
infrarouge émis par la surface de la Terre. L'augmentation de leur concentration dans l'atmosphère terrestre contribue
au réchauffement climatique."

Il représente 16,9 milliards de tonnes équivalent CO₂ soit les émissions d’un parc de plus de 12 millions de véhicules
parcourant plus de 12 000 km / an et émettant 112 g éq. CO₂ / km ou encore l’équivalent des émissions de plus de 2
millions d’habitants du monde.

### Épuisement des ressources abiotiques – éléments (minerais, métaux)

La définition de cet impact est la suivante : "L'exploitation industrielle entraîne une diminution des ressources
disponibles dont les réserves sont limitées. Cet indicateur évalue la quantité de ressources minérales et métalliques
extraites de la nature comme s'il s'agissait d'antimoine".

Le numérique en France contribue à l’épuisement des ressources abiotiques – éléments à hauteur de 948 tonnes équivalent
antimoine, soit près de 19 000 milliards de tonnes de terre excavée, ou encore, selon l’étude, l’équivalent de la
contribution de 15 millions d’habitants du monde.

### Épuisement des ressources abiotiques – fossiles

"L'indicateur représente la consommation d'énergie primaire provenant de différentes sources non renouvelables
(pétrole, gaz naturel, etc.). Contrairement à ce que le nom indique, la consommation d’énergie primaire issue de
l’uranium est également considérée. Les calculs sont basés sur le Pouvoir Calorifique Inférieur (PCI) des types
d'énergie considérés, exprimé en MJ/kg. Par exemple, 1 kg de pétrole apporteront 41,87 MJ à l'indicateur considéré."

Le numérique en France épuise ce type de ressource à hauteur de 796 milliards de mégajoules de ressources fossiles soit
la contribution à l’épuisement de ressources fossiles de 12 millions d’habitants du monde.

### Radiations ionisantes

"Les radionucléides peuvent être libérés lors de plusieurs activités humaines. Lorsque les radionucléides se
désintègrent, ils libèrent des rayonnements ionisants. L'exposition humaine aux rayonnements ionisants provoque des
dommages à l'ADN, qui à leur tour peuvent conduire à divers types de cancer et de malformations congénitales."

Le numérique en France contribue aux radiations ionisantes à la hauteur de 98 milliards de kilobecquerel équivalent
uranium 235 soit la radioactivité générée par les besoins de 25 millions d’habitants du monde.

### Écotoxicité, eaux douces

"Ces indicateurs suivent toute la chaîne d'impact depuis l'émission d'un composant chimique jusqu'à l'impact final sur
l'Homme et les écosystèmes. Cela comprend la modélisation de la distribution et du devenir dans l'environnement,
l'exposition des populations humaines et des écosystèmes, et les effets liés à la toxicité associés à l'exposition."

La contribution du numérique en France à l’écotoxicité est de 263 milliards d’unités de toxicité pour des écosystèmes.
Cela correspond à l’écotoxicité générée par 6 millions d’habitants du monde.

### Autres impacts

Trois impacts environnementaux, parmi bien d’autres, méritent d’être soulignés. L’acidification, les émissions de
particules fines et la création d’ozone photochimique sont des effets négatifs significatifs du numérique : leur
quantité est équivalente à ceux générés par un million d’habitants du monde.

__Définitions :__

- Acidification :
"L’acidification de l'air est liée aux émissions d'oxydes d'azote, d'oxydes de soufre,
d'ammoniac et d'acide chlorhydrique. Ces polluants se transforment en acides en présence d'humidité, et leurs retombées
peuvent endommager les écosystèmes ainsi que les bâtiments."

- Émissions de particules fines :
"La présence de particules
fines de petit diamètre dans l'air - en particulier celles d'un diamètre inférieur à 10 microns - représente un problème
de santé humaine, car leur inhalation peut provoquer des problèmes respiratoires et cardiovasculaires."

- Création d’ozone photochimique :
"L'ozone troposphérique se forme dans la basse atmosphère à partir de composés organiques volatils
(COV) et d'oxydes d'azote résultant du rayonnement solaire. L'ozone est un oxydant très puissant connu pour avoir des
effets sur la santé, car il pénètre facilement dans les voies respiratoires."

__Nota bene :__ "L’indicateur d’épuisement de la ressource en eau \[a donné\] des résultats non cohérents du fait d’une
surreprésentation de la fin de vie liée aux données utilisées. Ce point a été identifié \[par les auteurs\], mais n’a pas
pu être corrigé dans le temps de l’étude. Soyons conscient que le numérique contribue aussi fortement au stress
hydrique. [L’étude iNum : impacts environnementaux du numérique en France](https://www.greenit.fr/impacts-environnementaux-du-numerique-en-france/) de [GreenIT.fr](https://www.greenit.fr/), également basé sur une méthode ACV,
concluait que le numérique en France contribuait à la tension sur l’eau douce à hauteur de 559 millions de m³ d'eau
douce soit 5 fois la consommation d’eau des Parisiens."

### Impacts du numérique en France par habitant

L’impact annuel du numérique sur le changement climatique est de 235 kg éq. CO₂ par français, soit les émissions de gaz
à effet de serre équivalentes à celles d’un trajet de 2 259 km en voiture.

La production annuelle de déchets numériques est de 299 kg par habitant.

Pour répondre à ses besoins numériques un Français génère une masse de matériaux déplacée considérable de 932 kg chaque
année.

## Source des impacts du numérique en France

Par leur nombre les équipements des utilisateurs représentent 63 à 92% de ces impacts!

À part pour les indicateurs épuisement des ressources – fossiles, radiations ionisantes et émissions de particules
fines, auxquels l’utilisation de ces équipements, et donc la production d’électricité pour les alimenter, contribue le
plus, **c’est la fabrication des équipements des utilisateurs qui concentre la majorité des impacts** et ce pour deux
raisons :

- ces équipements requièrent une quantité importante de métaux et de minerais, dont l’extraction demande beaucoup
  d’énergie motrice – produite à partir de moteurs à explosion et d’hydrocarbures, de ressources et d’intrants
  chimiques, et engendre beaucoup de déchets ;
- la fabrication des équipements et infrastructures du numérique nécessite énormément d’énergie produite dans des pays
  avec un mix énergétique très carboné ainsi qu’une grande force motrice générée par des moteurs à explosion.

### Poids des différents équipements dans l’empreinte environnementale du numérique français

Par leur nombre et leurs impacts unitaires importants, tant pour les fabriquer que pour les utiliser, les téléviseurs
représentent 11 à 30% des impacts du numérique français. Ils participent particulièrement à l’épuisement des ressources
– éléments.

Viennent ensuite les ordinateurs portables et fixes, les smartphones, les box TV, les consoles de jeu vidéo, les
imprimantes et les autres écrans qui par leur nombre et leurs impacts unitaires élevés expliquent 5 à 15% des impacts.

Les objets connectés, peu impactants unitairement, mais très nombreux, contribuent pour la majorité des impacts, de 3 à
6% de l’empreinte environnementale du numérique en France.

### Réseau fixe VS réseau mobile

Les impacts environnementaux des réseaux mobiles sont plus importants que ceux des réseaux fixes, par quantité de
données transférées.

### Usages personnels VS usages professionnels

Les résultats de l’étude de l’ADEME et de l’ARCEP montrent que les usages professionnels contribuent de 37 à 48% des
impacts et les usages personnels contribuent de 42 à 63% des impacts.

## Recommandations et réponses de IT’s on us

La fabrication est la principale source d'impacts pour l'environnement. Cela s’explique notamment par la quantité
importante d’énergies fossiles nécessaire à leur production et à l'extraction des minerais. L’utilisation représente
"seulement" 21 % de la contribution au changement climatique en raison du mix énergétique peu carboné de la France.

Les auteurs de l'étude recommandent donc d’allonger au maximum la durée de vie des équipements "à travers la durabilité
des produits, le réemploi, le reconditionnement, l’économie de la fonctionnalité ou la réparation".

Les membres du collectif IT’s on us [accompagnent les organisations](https://www.itsonus.fr/nos_services/reduire_impacts_numerique/) et les aident à :
- utiliser moins d’équipements numériques et à les faire durer plus longtemps grâce à la démarche Numérique Responsable.
- écoconcevoir les services numériques en les dotant de couches applicatives fonctionnant sur de vieux équipements et
- [changer de modèle économique](https://www.itsonus.fr/nos_services/developper_modeles_durables/), quand elles appartiennent secteur du numérique, afin de sortir de la logique de volume
  et corréler leurs intérêts économiques avec les intérêts socio-environnementaux.
